# Release notes for MUSE v1.5.4 (January 16, 2026)

This release fixes a small bug to do with flexible input commodities (`github`{816}) and some small improvements to the documentation (`github`{813})
